@@ -11,6 +11,8 @@ MESSAGES = {
     "More posts about": "ارسال‌های بیشتر دربارهٔ",
     "Newer posts": "ارسال‌های جدید‌تر",
     "Next post": "ارسال بعدی",
+    "No posts found.": "",
+    "Nothing found.": "",
     "Older posts": "پست‌های قدیمی‌تر",
     "Original site": "سایت اصلی",
     "Posted": "ارسال شده",
