@@ -11,6 +11,8 @@ MESSAGES = {
     "More posts about": "Više postova o",
     "Newer posts": "Noviji postovi",
     "Next post": "Sljedeći post",
+    "No posts found.": "",
+    "Nothing found.": "",
     "Older posts": "Stariji postovi",
     "Original site": "Izvorna stranica",
     "Posted": "Objavljeno",
