@@ -11,6 +11,8 @@ MESSAGES = {
     "More posts about": "Mais posts sobre",
     "Newer posts": "Posts mais recentes",
     "Next post": "Próximo post",
+    "No posts found.": "",
+    "Nothing found.": "",
     "Older posts": "Posts mais antigos",
     "Original site": "Site original",
     "Posted": "Publicado",
