@@ -43,7 +43,7 @@ except ImportError:
 try:
     from collections import OrderedDict
 except ImportError:
-    OrderedDict = None  # NOQA
+    OrderedDict = dict  # NOQA
 
 from nikola.plugin_categories import PageCompiler
 from nikola.utils import makedirs, req_missing
@@ -62,11 +62,8 @@ class CompileTxt2tags(PageCompiler):
         cmd = ["-t", "html", "--no-headers", "--outfile", dest, source]
         txt2tags(cmd)
 
-    def create_post(self, path, onefile=False, **kw):
-        if OrderedDict is not None:
-            metadata = OrderedDict()
-        else:
-            metadata = {}
+    def create_post(self, path, onefile=False, is_page=False, **kw):
+        metadata = OrderedDict()
         metadata.update(self.default_metadata)
         metadata.update(kw)
         makedirs(os.path.dirname(path))
@@ -76,4 +73,4 @@ class CompileTxt2tags(PageCompiler):
                 for k, v in metadata.items():
                     fd.write('.. {0}: {1}\n'.format(k, v))
                 fd.write("-->\n'''\n")
-            fd.write("\nWrite your post here.")
+            fd.write("\nWrite your {0} here.".format('page' if is_page else 'post'))
