@@ -75,8 +75,8 @@ class CopyAssets(Task):
                 formatter = get_formatter_by_name('html', style=kw["code_color_scheme"])
                 utils.makedirs(os.path.dirname(code_css_path))
                 with codecs.open(code_css_path, 'wb+', 'utf8') as outf:
-                    outf.write(formatter.get_style_defs('.code'))
-                    outf.write("table.codetable { width: 100%;} td.linenos {text-align: right; width: 4em;}")
+                    outf.write(formatter.get_style_defs(['pre.code', 'div.code pre']))
+                    outf.write("\ntable.codetable { width: 100%;} td.linenos {text-align: right; width: 4em;}\n")
 
             task = {
                 'basename': self.name,
