@@ -176,6 +176,7 @@ class Galleries(Task):
 
                 thumbs = ['.thumbnail'.join(os.path.splitext(p)) for p in image_list]
                 thumbs = [os.path.join(self.kw['output_folder'], t) for t in thumbs]
+                dest_img_list = [os.path.join(self.kw['output_folder'], t) for t in image_list]
 
                 folders = []
 
@@ -193,7 +194,8 @@ class Galleries(Task):
                 context["folders"] = folders
                 context["crumbs"] = crumbs
                 context["permalink"] = self.site.link(
-                    "gallery", os.path.basename(gallery), lang)
+                    "gallery", os.path.basename(
+                        os.path.relpath(gallery, self.kw['gallery_path'])), lang)
                 # FIXME: use kw
                 context["enable_comments"] = (
                     self.site.config["COMMENTS_IN_GALLERIES"])
@@ -219,7 +221,7 @@ class Galleries(Task):
                             template_name,
                             dst,
                             context,
-                            image_list,
+                            dest_img_list,
                             thumbs,
                             file_dep))],
                     'clean': True,
