@@ -25,12 +25,12 @@ class CommandInitCallTest(unittest.TestCase):
         create_empty_site_patch = mock.patch(
             'nikola.plugins.command.init.CommandInit.create_empty_site', self.create_empty_site)
 
-        self.patches = [copy_sample_site_patch,
-                        create_configuration_patch, create_empty_site_patch]
+        self.patches = [copy_sample_site_patch, create_configuration_patch,
+                        create_empty_site_patch]
         for patch in self.patches:
             patch.start()
 
-        self.init_commad = nikola.plugins.command.init.CommandInit()
+        self.init_command = nikola.plugins.command.init.CommandInit()
 
     def tearDown(self):
         for patch in self.patches:
@@ -43,21 +43,21 @@ class CommandInitCallTest(unittest.TestCase):
 
     def test_init_default(self):
         for arguments in (dict(options={'demo': True}, args=['destination']), {}):
-            self.init_commad.execute(**arguments)
+            self.init_command.execute(**arguments)
 
             self.assertTrue(self.create_configuration.called)
             self.assertTrue(self.copy_sample_site.called)
             self.assertFalse(self.create_empty_site.called)
 
     def test_init_called_without_target(self):
-        self.init_commad.execute()
+        self.init_command.execute()
 
         self.assertFalse(self.create_configuration.called)
         self.assertFalse(self.copy_sample_site.called)
         self.assertFalse(self.create_empty_site.called)
 
     def test_init_empty_dir(self):
-        self.init_commad.execute(args=['destination'])
+        self.init_command.execute(args=['destination'])
 
         self.assertTrue(self.create_configuration.called)
         self.assertFalse(self.copy_sample_site.called)
